@@ -8,6 +8,10 @@ import queue
 from time import sleep
 
 class PriorityQueue:
+    '''
+    put() higher priority get() earlier. default priority is 5.
+
+    '''
     def __init__(self):
         self._queue = []
         self._count = 0
